# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AzureCredentialArgs', 'AzureCredential']

@pulumi.input_type
class AzureCredentialArgs:
    def __init__(__self__, *,
                 client_id: pulumi.Input[str],
                 client_secret: pulumi.Input[str],
                 stack_id: pulumi.Input[str],
                 tenant_id: pulumi.Input[str],
                 auto_discovery_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_discovery_tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]]] = None,
                 resource_tags_to_add_to_metrics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a AzureCredential resource.
        :param pulumi.Input[str] client_id: The client ID of the Azure Credential.
        :param pulumi.Input[str] client_secret: The client secret of the Azure Credential.
        :param pulumi.Input[str] tenant_id: The tenant ID of the Azure Credential.
        :param pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]] auto_discovery_configurations: The list of auto discovery configurations.
        :param pulumi.Input[str] name: The name of the Azure Credential.
        :param pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]] resource_discovery_tag_filters: The list of tag filters to apply to resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_tags_to_add_to_metrics: The list of resource tags to add to metrics.
        """
        pulumi.set(__self__, "client_id", client_id)
        pulumi.set(__self__, "client_secret", client_secret)
        pulumi.set(__self__, "stack_id", stack_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        if auto_discovery_configurations is not None:
            pulumi.set(__self__, "auto_discovery_configurations", auto_discovery_configurations)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_discovery_tag_filters is not None:
            pulumi.set(__self__, "resource_discovery_tag_filters", resource_discovery_tag_filters)
        if resource_tags_to_add_to_metrics is not None:
            pulumi.set(__self__, "resource_tags_to_add_to_metrics", resource_tags_to_add_to_metrics)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Input[str]:
        """
        The client ID of the Azure Credential.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Input[str]:
        """
        The client secret of the Azure Credential.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: pulumi.Input[str]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[str]:
        """
        The tenant ID of the Azure Credential.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter(name="autoDiscoveryConfigurations")
    def auto_discovery_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]]]:
        """
        The list of auto discovery configurations.
        """
        return pulumi.get(self, "auto_discovery_configurations")

    @auto_discovery_configurations.setter
    def auto_discovery_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]]]):
        pulumi.set(self, "auto_discovery_configurations", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Azure Credential.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceDiscoveryTagFilters")
    def resource_discovery_tag_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]]]:
        """
        The list of tag filters to apply to resources.
        """
        return pulumi.get(self, "resource_discovery_tag_filters")

    @resource_discovery_tag_filters.setter
    def resource_discovery_tag_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]]]):
        pulumi.set(self, "resource_discovery_tag_filters", value)

    @property
    @pulumi.getter(name="resourceTagsToAddToMetrics")
    def resource_tags_to_add_to_metrics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of resource tags to add to metrics.
        """
        return pulumi.get(self, "resource_tags_to_add_to_metrics")

    @resource_tags_to_add_to_metrics.setter
    def resource_tags_to_add_to_metrics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resource_tags_to_add_to_metrics", value)


@pulumi.input_type
class _AzureCredentialState:
    def __init__(__self__, *,
                 auto_discovery_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_discovery_tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]]] = None,
                 resource_id: Optional[pulumi.Input[str]] = None,
                 resource_tags_to_add_to_metrics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 stack_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AzureCredential resources.
        :param pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]] auto_discovery_configurations: The list of auto discovery configurations.
        :param pulumi.Input[str] client_id: The client ID of the Azure Credential.
        :param pulumi.Input[str] client_secret: The client secret of the Azure Credential.
        :param pulumi.Input[str] name: The name of the Azure Credential.
        :param pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]] resource_discovery_tag_filters: The list of tag filters to apply to resources.
        :param pulumi.Input[str] resource_id: The ID given by the Grafana Cloud Provider API to this Azure Credential resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_tags_to_add_to_metrics: The list of resource tags to add to metrics.
        :param pulumi.Input[str] tenant_id: The tenant ID of the Azure Credential.
        """
        if auto_discovery_configurations is not None:
            pulumi.set(__self__, "auto_discovery_configurations", auto_discovery_configurations)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_discovery_tag_filters is not None:
            pulumi.set(__self__, "resource_discovery_tag_filters", resource_discovery_tag_filters)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if resource_tags_to_add_to_metrics is not None:
            pulumi.set(__self__, "resource_tags_to_add_to_metrics", resource_tags_to_add_to_metrics)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="autoDiscoveryConfigurations")
    def auto_discovery_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]]]:
        """
        The list of auto discovery configurations.
        """
        return pulumi.get(self, "auto_discovery_configurations")

    @auto_discovery_configurations.setter
    def auto_discovery_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialAutoDiscoveryConfigurationArgs']]]]):
        pulumi.set(self, "auto_discovery_configurations", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[str]]:
        """
        The client ID of the Azure Credential.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[str]]:
        """
        The client secret of the Azure Credential.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Azure Credential.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceDiscoveryTagFilters")
    def resource_discovery_tag_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]]]:
        """
        The list of tag filters to apply to resources.
        """
        return pulumi.get(self, "resource_discovery_tag_filters")

    @resource_discovery_tag_filters.setter
    def resource_discovery_tag_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureCredentialResourceDiscoveryTagFilterArgs']]]]):
        pulumi.set(self, "resource_discovery_tag_filters", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID given by the Grafana Cloud Provider API to this Azure Credential resource.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceTagsToAddToMetrics")
    def resource_tags_to_add_to_metrics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of resource tags to add to metrics.
        """
        return pulumi.get(self, "resource_tags_to_add_to_metrics")

    @resource_tags_to_add_to_metrics.setter
    def resource_tags_to_add_to_metrics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resource_tags_to_add_to_metrics", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The tenant ID of the Azure Credential.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


class AzureCredential(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_discovery_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialAutoDiscoveryConfigurationArgs', 'AzureCredentialAutoDiscoveryConfigurationArgsDict']]]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_discovery_tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialResourceDiscoveryTagFilterArgs', 'AzureCredentialResourceDiscoveryTagFilterArgsDict']]]]] = None,
                 resource_tags_to_add_to_metrics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 stack_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ## Import

        ```sh
        $ pulumi import grafana:cloudProvider/azureCredential:AzureCredential name "{{ stack_id }}:{{ resource_id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialAutoDiscoveryConfigurationArgs', 'AzureCredentialAutoDiscoveryConfigurationArgsDict']]]] auto_discovery_configurations: The list of auto discovery configurations.
        :param pulumi.Input[str] client_id: The client ID of the Azure Credential.
        :param pulumi.Input[str] client_secret: The client secret of the Azure Credential.
        :param pulumi.Input[str] name: The name of the Azure Credential.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialResourceDiscoveryTagFilterArgs', 'AzureCredentialResourceDiscoveryTagFilterArgsDict']]]] resource_discovery_tag_filters: The list of tag filters to apply to resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_tags_to_add_to_metrics: The list of resource tags to add to metrics.
        :param pulumi.Input[str] tenant_id: The tenant ID of the Azure Credential.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AzureCredentialArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ## Import

        ```sh
        $ pulumi import grafana:cloudProvider/azureCredential:AzureCredential name "{{ stack_id }}:{{ resource_id }}"
        ```

        :param str resource_name: The name of the resource.
        :param AzureCredentialArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AzureCredentialArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_discovery_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialAutoDiscoveryConfigurationArgs', 'AzureCredentialAutoDiscoveryConfigurationArgsDict']]]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_discovery_tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialResourceDiscoveryTagFilterArgs', 'AzureCredentialResourceDiscoveryTagFilterArgsDict']]]]] = None,
                 resource_tags_to_add_to_metrics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 stack_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AzureCredentialArgs.__new__(AzureCredentialArgs)

            __props__.__dict__["auto_discovery_configurations"] = auto_discovery_configurations
            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__.__dict__["client_id"] = client_id
            if client_secret is None and not opts.urn:
                raise TypeError("Missing required property 'client_secret'")
            __props__.__dict__["client_secret"] = None if client_secret is None else pulumi.Output.secret(client_secret)
            __props__.__dict__["name"] = name
            __props__.__dict__["resource_discovery_tag_filters"] = resource_discovery_tag_filters
            __props__.__dict__["resource_tags_to_add_to_metrics"] = resource_tags_to_add_to_metrics
            if stack_id is None and not opts.urn:
                raise TypeError("Missing required property 'stack_id'")
            __props__.__dict__["stack_id"] = stack_id
            if tenant_id is None and not opts.urn:
                raise TypeError("Missing required property 'tenant_id'")
            __props__.__dict__["tenant_id"] = tenant_id
            __props__.__dict__["resource_id"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:cloud/providerAzureCredential:ProviderAzureCredential")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["clientSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(AzureCredential, __self__).__init__(
            'grafana:cloudProvider/azureCredential:AzureCredential',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_discovery_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialAutoDiscoveryConfigurationArgs', 'AzureCredentialAutoDiscoveryConfigurationArgsDict']]]]] = None,
            client_id: Optional[pulumi.Input[str]] = None,
            client_secret: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            resource_discovery_tag_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialResourceDiscoveryTagFilterArgs', 'AzureCredentialResourceDiscoveryTagFilterArgsDict']]]]] = None,
            resource_id: Optional[pulumi.Input[str]] = None,
            resource_tags_to_add_to_metrics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            stack_id: Optional[pulumi.Input[str]] = None,
            tenant_id: Optional[pulumi.Input[str]] = None) -> 'AzureCredential':
        """
        Get an existing AzureCredential resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialAutoDiscoveryConfigurationArgs', 'AzureCredentialAutoDiscoveryConfigurationArgsDict']]]] auto_discovery_configurations: The list of auto discovery configurations.
        :param pulumi.Input[str] client_id: The client ID of the Azure Credential.
        :param pulumi.Input[str] client_secret: The client secret of the Azure Credential.
        :param pulumi.Input[str] name: The name of the Azure Credential.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AzureCredentialResourceDiscoveryTagFilterArgs', 'AzureCredentialResourceDiscoveryTagFilterArgsDict']]]] resource_discovery_tag_filters: The list of tag filters to apply to resources.
        :param pulumi.Input[str] resource_id: The ID given by the Grafana Cloud Provider API to this Azure Credential resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_tags_to_add_to_metrics: The list of resource tags to add to metrics.
        :param pulumi.Input[str] tenant_id: The tenant ID of the Azure Credential.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AzureCredentialState.__new__(_AzureCredentialState)

        __props__.__dict__["auto_discovery_configurations"] = auto_discovery_configurations
        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["client_secret"] = client_secret
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_discovery_tag_filters"] = resource_discovery_tag_filters
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["resource_tags_to_add_to_metrics"] = resource_tags_to_add_to_metrics
        __props__.__dict__["stack_id"] = stack_id
        __props__.__dict__["tenant_id"] = tenant_id
        return AzureCredential(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoDiscoveryConfigurations")
    def auto_discovery_configurations(self) -> pulumi.Output[Optional[Sequence['outputs.AzureCredentialAutoDiscoveryConfiguration']]]:
        """
        The list of auto discovery configurations.
        """
        return pulumi.get(self, "auto_discovery_configurations")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[str]:
        """
        The client ID of the Azure Credential.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[str]:
        """
        The client secret of the Azure Credential.
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Azure Credential.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceDiscoveryTagFilters")
    def resource_discovery_tag_filters(self) -> pulumi.Output[Optional[Sequence['outputs.AzureCredentialResourceDiscoveryTagFilter']]]:
        """
        The list of tag filters to apply to resources.
        """
        return pulumi.get(self, "resource_discovery_tag_filters")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[str]:
        """
        The ID given by the Grafana Cloud Provider API to this Azure Credential resource.
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="resourceTagsToAddToMetrics")
    def resource_tags_to_add_to_metrics(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list of resource tags to add to metrics.
        """
        return pulumi.get(self, "resource_tags_to_add_to_metrics")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[str]:
        """
        The tenant ID of the Azure Credential.
        """
        return pulumi.get(self, "tenant_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .escalation import *
from .escalation_chain import *
from .get_escalation_chain import *
from .get_integration import *
from .get_outgoing_webhook import *
from .get_schedule import *
from .get_slack_channel import *
from .get_team import *
from .get_user import *
from .get_user_group import *
from .get_users import *
from .integration import *
from .on_call_shift import *
from .outgoing_webhook import *
from .route import *
from .schedule import *
from .user_notification_rule import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'IntegrationDefaultRouteArgs',
    'IntegrationDefaultRouteArgsDict',
    'IntegrationDefaultRouteMsteamsArgs',
    'IntegrationDefaultRouteMsteamsArgsDict',
    'IntegrationDefaultRouteSlackArgs',
    'IntegrationDefaultRouteSlackArgsDict',
    'IntegrationDefaultRouteTelegramArgs',
    'IntegrationDefaultRouteTelegramArgsDict',
    'IntegrationTemplatesArgs',
    'IntegrationTemplatesArgsDict',
    'IntegrationTemplatesEmailArgs',
    'IntegrationTemplatesEmailArgsDict',
    'IntegrationTemplatesMicrosoftTeamsArgs',
    'IntegrationTemplatesMicrosoftTeamsArgsDict',
    'IntegrationTemplatesMobileAppArgs',
    'IntegrationTemplatesMobileAppArgsDict',
    'IntegrationTemplatesPhoneCallArgs',
    'IntegrationTemplatesPhoneCallArgsDict',
    'IntegrationTemplatesSlackArgs',
    'IntegrationTemplatesSlackArgsDict',
    'IntegrationTemplatesSmsArgs',
    'IntegrationTemplatesSmsArgsDict',
    'IntegrationTemplatesTelegramArgs',
    'IntegrationTemplatesTelegramArgsDict',
    'IntegrationTemplatesWebArgs',
    'IntegrationTemplatesWebArgsDict',
    'RouteMsteamsArgs',
    'RouteMsteamsArgsDict',
    'RouteSlackArgs',
    'RouteSlackArgsDict',
    'RouteTelegramArgs',
    'RouteTelegramArgsDict',
    'ScheduleSlackArgs',
    'ScheduleSlackArgsDict',
]

MYPY = False

if not MYPY:
    class IntegrationDefaultRouteArgsDict(TypedDict):
        escalation_chain_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the escalation chain.
        """
        id: NotRequired[pulumi.Input[str]]
        msteams: NotRequired[pulumi.Input['IntegrationDefaultRouteMsteamsArgsDict']]
        """
        MS teams-specific settings for a route.
        """
        slack: NotRequired[pulumi.Input['IntegrationDefaultRouteSlackArgsDict']]
        """
        Slack-specific settings for a route.
        """
        telegram: NotRequired[pulumi.Input['IntegrationDefaultRouteTelegramArgsDict']]
        """
        Telegram-specific settings for a route.
        """
elif False:
    IntegrationDefaultRouteArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationDefaultRouteArgs:
    def __init__(__self__, *,
                 escalation_chain_id: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 msteams: Optional[pulumi.Input['IntegrationDefaultRouteMsteamsArgs']] = None,
                 slack: Optional[pulumi.Input['IntegrationDefaultRouteSlackArgs']] = None,
                 telegram: Optional[pulumi.Input['IntegrationDefaultRouteTelegramArgs']] = None):
        """
        :param pulumi.Input[str] escalation_chain_id: The ID of the escalation chain.
        :param pulumi.Input['IntegrationDefaultRouteMsteamsArgs'] msteams: MS teams-specific settings for a route.
        :param pulumi.Input['IntegrationDefaultRouteSlackArgs'] slack: Slack-specific settings for a route.
        :param pulumi.Input['IntegrationDefaultRouteTelegramArgs'] telegram: Telegram-specific settings for a route.
        """
        if escalation_chain_id is not None:
            pulumi.set(__self__, "escalation_chain_id", escalation_chain_id)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if msteams is not None:
            pulumi.set(__self__, "msteams", msteams)
        if slack is not None:
            pulumi.set(__self__, "slack", slack)
        if telegram is not None:
            pulumi.set(__self__, "telegram", telegram)

    @property
    @pulumi.getter(name="escalationChainId")
    def escalation_chain_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the escalation chain.
        """
        return pulumi.get(self, "escalation_chain_id")

    @escalation_chain_id.setter
    def escalation_chain_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "escalation_chain_id", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def msteams(self) -> Optional[pulumi.Input['IntegrationDefaultRouteMsteamsArgs']]:
        """
        MS teams-specific settings for a route.
        """
        return pulumi.get(self, "msteams")

    @msteams.setter
    def msteams(self, value: Optional[pulumi.Input['IntegrationDefaultRouteMsteamsArgs']]):
        pulumi.set(self, "msteams", value)

    @property
    @pulumi.getter
    def slack(self) -> Optional[pulumi.Input['IntegrationDefaultRouteSlackArgs']]:
        """
        Slack-specific settings for a route.
        """
        return pulumi.get(self, "slack")

    @slack.setter
    def slack(self, value: Optional[pulumi.Input['IntegrationDefaultRouteSlackArgs']]):
        pulumi.set(self, "slack", value)

    @property
    @pulumi.getter
    def telegram(self) -> Optional[pulumi.Input['IntegrationDefaultRouteTelegramArgs']]:
        """
        Telegram-specific settings for a route.
        """
        return pulumi.get(self, "telegram")

    @telegram.setter
    def telegram(self, value: Optional[pulumi.Input['IntegrationDefaultRouteTelegramArgs']]):
        pulumi.set(self, "telegram", value)


if not MYPY:
    class IntegrationDefaultRouteMsteamsArgsDict(TypedDict):
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Enable notification in MS teams. Defaults to `true`.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        MS teams channel id. Alerts will be directed to this channel in Microsoft teams.
        """
elif False:
    IntegrationDefaultRouteMsteamsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationDefaultRouteMsteamsArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] enabled: Enable notification in MS teams. Defaults to `true`.
        :param pulumi.Input[str] id: MS teams channel id. Alerts will be directed to this channel in Microsoft teams.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notification in MS teams. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        MS teams channel id. Alerts will be directed to this channel in Microsoft teams.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class IntegrationDefaultRouteSlackArgsDict(TypedDict):
        channel_id: NotRequired[pulumi.Input[str]]
        """
        Slack channel id. Alerts will be directed to this channel in Slack.
        """
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Enable notification in Slack. Defaults to `true`.
        """
elif False:
    IntegrationDefaultRouteSlackArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationDefaultRouteSlackArgs:
    def __init__(__self__, *,
                 channel_id: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] channel_id: Slack channel id. Alerts will be directed to this channel in Slack.
        :param pulumi.Input[bool] enabled: Enable notification in Slack. Defaults to `true`.
        """
        if channel_id is not None:
            pulumi.set(__self__, "channel_id", channel_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @property
    @pulumi.getter(name="channelId")
    def channel_id(self) -> Optional[pulumi.Input[str]]:
        """
        Slack channel id. Alerts will be directed to this channel in Slack.
        """
        return pulumi.get(self, "channel_id")

    @channel_id.setter
    def channel_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "channel_id", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notification in Slack. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)


if not MYPY:
    class IntegrationDefaultRouteTelegramArgsDict(TypedDict):
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Enable notification in Telegram. Defaults to `true`.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        Telegram channel id. Alerts will be directed to this channel in Telegram.
        """
elif False:
    IntegrationDefaultRouteTelegramArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationDefaultRouteTelegramArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] enabled: Enable notification in Telegram. Defaults to `true`.
        :param pulumi.Input[str] id: Telegram channel id. Alerts will be directed to this channel in Telegram.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notification in Telegram. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        Telegram channel id. Alerts will be directed to this channel in Telegram.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class IntegrationTemplatesArgsDict(TypedDict):
        acknowledge_signal: NotRequired[pulumi.Input[str]]
        """
        Template for sending a signal to acknowledge the Incident.
        """
        email: NotRequired[pulumi.Input['IntegrationTemplatesEmailArgsDict']]
        """
        Templates for Email.
        """
        grouping_key: NotRequired[pulumi.Input[str]]
        """
        Template for the key by which alerts are grouped.
        """
        microsoft_teams: NotRequired[pulumi.Input['IntegrationTemplatesMicrosoftTeamsArgsDict']]
        """
        Templates for Microsoft Teams. **NOTE**: Microsoft Teams templates are only available on Grafana Cloud.
        """
        mobile_app: NotRequired[pulumi.Input['IntegrationTemplatesMobileAppArgsDict']]
        """
        Templates for Mobile app push notifications.
        """
        phone_call: NotRequired[pulumi.Input['IntegrationTemplatesPhoneCallArgsDict']]
        """
        Templates for Phone Call.
        """
        resolve_signal: NotRequired[pulumi.Input[str]]
        """
        Template for sending a signal to resolve the Incident.
        """
        slack: NotRequired[pulumi.Input['IntegrationTemplatesSlackArgsDict']]
        """
        Templates for Slack.
        """
        sms: NotRequired[pulumi.Input['IntegrationTemplatesSmsArgsDict']]
        """
        Templates for SMS.
        """
        source_link: NotRequired[pulumi.Input[str]]
        """
        Template for a source link.
        """
        telegram: NotRequired[pulumi.Input['IntegrationTemplatesTelegramArgsDict']]
        """
        Templates for Telegram.
        """
        web: NotRequired[pulumi.Input['IntegrationTemplatesWebArgsDict']]
        """
        Templates for Web.
        """
elif False:
    IntegrationTemplatesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesArgs:
    def __init__(__self__, *,
                 acknowledge_signal: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input['IntegrationTemplatesEmailArgs']] = None,
                 grouping_key: Optional[pulumi.Input[str]] = None,
                 microsoft_teams: Optional[pulumi.Input['IntegrationTemplatesMicrosoftTeamsArgs']] = None,
                 mobile_app: Optional[pulumi.Input['IntegrationTemplatesMobileAppArgs']] = None,
                 phone_call: Optional[pulumi.Input['IntegrationTemplatesPhoneCallArgs']] = None,
                 resolve_signal: Optional[pulumi.Input[str]] = None,
                 slack: Optional[pulumi.Input['IntegrationTemplatesSlackArgs']] = None,
                 sms: Optional[pulumi.Input['IntegrationTemplatesSmsArgs']] = None,
                 source_link: Optional[pulumi.Input[str]] = None,
                 telegram: Optional[pulumi.Input['IntegrationTemplatesTelegramArgs']] = None,
                 web: Optional[pulumi.Input['IntegrationTemplatesWebArgs']] = None):
        """
        :param pulumi.Input[str] acknowledge_signal: Template for sending a signal to acknowledge the Incident.
        :param pulumi.Input['IntegrationTemplatesEmailArgs'] email: Templates for Email.
        :param pulumi.Input[str] grouping_key: Template for the key by which alerts are grouped.
        :param pulumi.Input['IntegrationTemplatesMicrosoftTeamsArgs'] microsoft_teams: Templates for Microsoft Teams. **NOTE**: Microsoft Teams templates are only available on Grafana Cloud.
        :param pulumi.Input['IntegrationTemplatesMobileAppArgs'] mobile_app: Templates for Mobile app push notifications.
        :param pulumi.Input['IntegrationTemplatesPhoneCallArgs'] phone_call: Templates for Phone Call.
        :param pulumi.Input[str] resolve_signal: Template for sending a signal to resolve the Incident.
        :param pulumi.Input['IntegrationTemplatesSlackArgs'] slack: Templates for Slack.
        :param pulumi.Input['IntegrationTemplatesSmsArgs'] sms: Templates for SMS.
        :param pulumi.Input[str] source_link: Template for a source link.
        :param pulumi.Input['IntegrationTemplatesTelegramArgs'] telegram: Templates for Telegram.
        :param pulumi.Input['IntegrationTemplatesWebArgs'] web: Templates for Web.
        """
        if acknowledge_signal is not None:
            pulumi.set(__self__, "acknowledge_signal", acknowledge_signal)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if grouping_key is not None:
            pulumi.set(__self__, "grouping_key", grouping_key)
        if microsoft_teams is not None:
            pulumi.set(__self__, "microsoft_teams", microsoft_teams)
        if mobile_app is not None:
            pulumi.set(__self__, "mobile_app", mobile_app)
        if phone_call is not None:
            pulumi.set(__self__, "phone_call", phone_call)
        if resolve_signal is not None:
            pulumi.set(__self__, "resolve_signal", resolve_signal)
        if slack is not None:
            pulumi.set(__self__, "slack", slack)
        if sms is not None:
            pulumi.set(__self__, "sms", sms)
        if source_link is not None:
            pulumi.set(__self__, "source_link", source_link)
        if telegram is not None:
            pulumi.set(__self__, "telegram", telegram)
        if web is not None:
            pulumi.set(__self__, "web", web)

    @property
    @pulumi.getter(name="acknowledgeSignal")
    def acknowledge_signal(self) -> Optional[pulumi.Input[str]]:
        """
        Template for sending a signal to acknowledge the Incident.
        """
        return pulumi.get(self, "acknowledge_signal")

    @acknowledge_signal.setter
    def acknowledge_signal(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "acknowledge_signal", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input['IntegrationTemplatesEmailArgs']]:
        """
        Templates for Email.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input['IntegrationTemplatesEmailArgs']]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="groupingKey")
    def grouping_key(self) -> Optional[pulumi.Input[str]]:
        """
        Template for the key by which alerts are grouped.
        """
        return pulumi.get(self, "grouping_key")

    @grouping_key.setter
    def grouping_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "grouping_key", value)

    @property
    @pulumi.getter(name="microsoftTeams")
    def microsoft_teams(self) -> Optional[pulumi.Input['IntegrationTemplatesMicrosoftTeamsArgs']]:
        """
        Templates for Microsoft Teams. **NOTE**: Microsoft Teams templates are only available on Grafana Cloud.
        """
        return pulumi.get(self, "microsoft_teams")

    @microsoft_teams.setter
    def microsoft_teams(self, value: Optional[pulumi.Input['IntegrationTemplatesMicrosoftTeamsArgs']]):
        pulumi.set(self, "microsoft_teams", value)

    @property
    @pulumi.getter(name="mobileApp")
    def mobile_app(self) -> Optional[pulumi.Input['IntegrationTemplatesMobileAppArgs']]:
        """
        Templates for Mobile app push notifications.
        """
        return pulumi.get(self, "mobile_app")

    @mobile_app.setter
    def mobile_app(self, value: Optional[pulumi.Input['IntegrationTemplatesMobileAppArgs']]):
        pulumi.set(self, "mobile_app", value)

    @property
    @pulumi.getter(name="phoneCall")
    def phone_call(self) -> Optional[pulumi.Input['IntegrationTemplatesPhoneCallArgs']]:
        """
        Templates for Phone Call.
        """
        return pulumi.get(self, "phone_call")

    @phone_call.setter
    def phone_call(self, value: Optional[pulumi.Input['IntegrationTemplatesPhoneCallArgs']]):
        pulumi.set(self, "phone_call", value)

    @property
    @pulumi.getter(name="resolveSignal")
    def resolve_signal(self) -> Optional[pulumi.Input[str]]:
        """
        Template for sending a signal to resolve the Incident.
        """
        return pulumi.get(self, "resolve_signal")

    @resolve_signal.setter
    def resolve_signal(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resolve_signal", value)

    @property
    @pulumi.getter
    def slack(self) -> Optional[pulumi.Input['IntegrationTemplatesSlackArgs']]:
        """
        Templates for Slack.
        """
        return pulumi.get(self, "slack")

    @slack.setter
    def slack(self, value: Optional[pulumi.Input['IntegrationTemplatesSlackArgs']]):
        pulumi.set(self, "slack", value)

    @property
    @pulumi.getter
    def sms(self) -> Optional[pulumi.Input['IntegrationTemplatesSmsArgs']]:
        """
        Templates for SMS.
        """
        return pulumi.get(self, "sms")

    @sms.setter
    def sms(self, value: Optional[pulumi.Input['IntegrationTemplatesSmsArgs']]):
        pulumi.set(self, "sms", value)

    @property
    @pulumi.getter(name="sourceLink")
    def source_link(self) -> Optional[pulumi.Input[str]]:
        """
        Template for a source link.
        """
        return pulumi.get(self, "source_link")

    @source_link.setter
    def source_link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_link", value)

    @property
    @pulumi.getter
    def telegram(self) -> Optional[pulumi.Input['IntegrationTemplatesTelegramArgs']]:
        """
        Templates for Telegram.
        """
        return pulumi.get(self, "telegram")

    @telegram.setter
    def telegram(self, value: Optional[pulumi.Input['IntegrationTemplatesTelegramArgs']]):
        pulumi.set(self, "telegram", value)

    @property
    @pulumi.getter
    def web(self) -> Optional[pulumi.Input['IntegrationTemplatesWebArgs']]:
        """
        Templates for Web.
        """
        return pulumi.get(self, "web")

    @web.setter
    def web(self, value: Optional[pulumi.Input['IntegrationTemplatesWebArgs']]):
        pulumi.set(self, "web", value)


if not MYPY:
    class IntegrationTemplatesEmailArgsDict(TypedDict):
        message: NotRequired[pulumi.Input[str]]
        """
        Template for Alert message.
        """
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesEmailArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesEmailArgs:
    def __init__(__self__, *,
                 message: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] message: Template for Alert message.
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if message is not None:
            pulumi.set(__self__, "message", message)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert message.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class IntegrationTemplatesMicrosoftTeamsArgsDict(TypedDict):
        image_url: NotRequired[pulumi.Input[str]]
        """
        Template for Alert image url.
        """
        message: NotRequired[pulumi.Input[str]]
        """
        Template for Alert message.
        """
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesMicrosoftTeamsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesMicrosoftTeamsArgs:
    def __init__(__self__, *,
                 image_url: Optional[pulumi.Input[str]] = None,
                 message: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] image_url: Template for Alert image url.
        :param pulumi.Input[str] message: Template for Alert message.
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert image url.
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert message.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class IntegrationTemplatesMobileAppArgsDict(TypedDict):
        message: NotRequired[pulumi.Input[str]]
        """
        Template for Alert message.
        """
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesMobileAppArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesMobileAppArgs:
    def __init__(__self__, *,
                 message: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] message: Template for Alert message.
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if message is not None:
            pulumi.set(__self__, "message", message)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert message.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class IntegrationTemplatesPhoneCallArgsDict(TypedDict):
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesPhoneCallArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesPhoneCallArgs:
    def __init__(__self__, *,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class IntegrationTemplatesSlackArgsDict(TypedDict):
        image_url: NotRequired[pulumi.Input[str]]
        """
        Template for Alert image url.
        """
        message: NotRequired[pulumi.Input[str]]
        """
        Template for Alert message.
        """
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesSlackArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesSlackArgs:
    def __init__(__self__, *,
                 image_url: Optional[pulumi.Input[str]] = None,
                 message: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] image_url: Template for Alert image url.
        :param pulumi.Input[str] message: Template for Alert message.
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert image url.
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert message.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class IntegrationTemplatesSmsArgsDict(TypedDict):
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesSmsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesSmsArgs:
    def __init__(__self__, *,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class IntegrationTemplatesTelegramArgsDict(TypedDict):
        image_url: NotRequired[pulumi.Input[str]]
        """
        Template for Alert image url.
        """
        message: NotRequired[pulumi.Input[str]]
        """
        Template for Alert message.
        """
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesTelegramArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesTelegramArgs:
    def __init__(__self__, *,
                 image_url: Optional[pulumi.Input[str]] = None,
                 message: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] image_url: Template for Alert image url.
        :param pulumi.Input[str] message: Template for Alert message.
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert image url.
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert message.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class IntegrationTemplatesWebArgsDict(TypedDict):
        image_url: NotRequired[pulumi.Input[str]]
        """
        Template for Alert image url.
        """
        message: NotRequired[pulumi.Input[str]]
        """
        Template for Alert message.
        """
        title: NotRequired[pulumi.Input[str]]
        """
        Template for Alert title.
        """
elif False:
    IntegrationTemplatesWebArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationTemplatesWebArgs:
    def __init__(__self__, *,
                 image_url: Optional[pulumi.Input[str]] = None,
                 message: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] image_url: Template for Alert image url.
        :param pulumi.Input[str] message: Template for Alert message.
        :param pulumi.Input[str] title: Template for Alert title.
        """
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert image url.
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert message.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Template for Alert title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class RouteMsteamsArgsDict(TypedDict):
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Enable notification in MS teams. Defaults to `true`.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        MS teams channel id. Alerts will be directed to this channel in Microsoft teams.
        """
elif False:
    RouteMsteamsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteMsteamsArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] enabled: Enable notification in MS teams. Defaults to `true`.
        :param pulumi.Input[str] id: MS teams channel id. Alerts will be directed to this channel in Microsoft teams.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notification in MS teams. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        MS teams channel id. Alerts will be directed to this channel in Microsoft teams.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class RouteSlackArgsDict(TypedDict):
        channel_id: NotRequired[pulumi.Input[str]]
        """
        Slack channel id. Alerts will be directed to this channel in Slack.
        """
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Enable notification in Slack. Defaults to `true`.
        """
elif False:
    RouteSlackArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteSlackArgs:
    def __init__(__self__, *,
                 channel_id: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] channel_id: Slack channel id. Alerts will be directed to this channel in Slack.
        :param pulumi.Input[bool] enabled: Enable notification in Slack. Defaults to `true`.
        """
        if channel_id is not None:
            pulumi.set(__self__, "channel_id", channel_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @property
    @pulumi.getter(name="channelId")
    def channel_id(self) -> Optional[pulumi.Input[str]]:
        """
        Slack channel id. Alerts will be directed to this channel in Slack.
        """
        return pulumi.get(self, "channel_id")

    @channel_id.setter
    def channel_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "channel_id", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notification in Slack. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)


if not MYPY:
    class RouteTelegramArgsDict(TypedDict):
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Enable notification in Telegram. Defaults to `true`.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        Telegram channel id. Alerts will be directed to this channel in Telegram.
        """
elif False:
    RouteTelegramArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteTelegramArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] enabled: Enable notification in Telegram. Defaults to `true`.
        :param pulumi.Input[str] id: Telegram channel id. Alerts will be directed to this channel in Telegram.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notification in Telegram. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        Telegram channel id. Alerts will be directed to this channel in Telegram.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class ScheduleSlackArgsDict(TypedDict):
        channel_id: NotRequired[pulumi.Input[str]]
        """
        Slack channel id. Reminder about schedule shifts will be directed to this channel in Slack.
        """
        user_group_id: NotRequired[pulumi.Input[str]]
        """
        Slack user group id. Members of user group will be updated when on-call users change.
        """
elif False:
    ScheduleSlackArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScheduleSlackArgs:
    def __init__(__self__, *,
                 channel_id: Optional[pulumi.Input[str]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] channel_id: Slack channel id. Reminder about schedule shifts will be directed to this channel in Slack.
        :param pulumi.Input[str] user_group_id: Slack user group id. Members of user group will be updated when on-call users change.
        """
        if channel_id is not None:
            pulumi.set(__self__, "channel_id", channel_id)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)

    @property
    @pulumi.getter(name="channelId")
    def channel_id(self) -> Optional[pulumi.Input[str]]:
        """
        Slack channel id. Reminder about schedule shifts will be directed to this channel in Slack.
        """
        return pulumi.get(self, "channel_id")

    @channel_id.setter
    def channel_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "channel_id", value)

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        Slack user group id. Members of user group will be updated when on-call users change.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_group_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetStackResult',
    'AwaitableGetStackResult',
    'get_stack',
    'get_stack_output',
]

@pulumi.output_type
class GetStackResult:
    """
    A collection of values returned by getStack.
    """
    def __init__(__self__, alertmanager_ip_allow_list_cname=None, alertmanager_name=None, alertmanager_status=None, alertmanager_url=None, alertmanager_user_id=None, cluster_slug=None, description=None, fleet_management_name=None, fleet_management_status=None, fleet_management_url=None, fleet_management_user_id=None, grafanas_ip_allow_list_cname=None, graphite_ip_allow_list_cname=None, graphite_name=None, graphite_private_connectivity_info_private_dns=None, graphite_private_connectivity_info_service_name=None, graphite_status=None, graphite_url=None, graphite_user_id=None, id=None, influx_url=None, labels=None, logs_ip_allow_list_cname=None, logs_name=None, logs_private_connectivity_info_private_dns=None, logs_private_connectivity_info_service_name=None, logs_status=None, logs_url=None, logs_user_id=None, name=None, org_id=None, org_name=None, org_slug=None, otlp_private_connectivity_info_private_dns=None, otlp_private_connectivity_info_service_name=None, otlp_url=None, pdc_api_private_connectivity_info_private_dns=None, pdc_api_private_connectivity_info_service_name=None, pdc_gateway_private_connectivity_info_private_dns=None, pdc_gateway_private_connectivity_info_service_name=None, profiles_ip_allow_list_cname=None, profiles_name=None, profiles_private_connectivity_info_private_dns=None, profiles_private_connectivity_info_service_name=None, profiles_status=None, profiles_url=None, profiles_user_id=None, prometheus_ip_allow_list_cname=None, prometheus_name=None, prometheus_private_connectivity_info_private_dns=None, prometheus_private_connectivity_info_service_name=None, prometheus_remote_endpoint=None, prometheus_remote_write_endpoint=None, prometheus_status=None, prometheus_url=None, prometheus_user_id=None, region_slug=None, slug=None, status=None, traces_ip_allow_list_cname=None, traces_name=None, traces_private_connectivity_info_private_dns=None, traces_private_connectivity_info_service_name=None, traces_status=None, traces_url=None, traces_user_id=None, url=None):
        if alertmanager_ip_allow_list_cname and not isinstance(alertmanager_ip_allow_list_cname, str):
            raise TypeError("Expected argument 'alertmanager_ip_allow_list_cname' to be a str")
        pulumi.set(__self__, "alertmanager_ip_allow_list_cname", alertmanager_ip_allow_list_cname)
        if alertmanager_name and not isinstance(alertmanager_name, str):
            raise TypeError("Expected argument 'alertmanager_name' to be a str")
        pulumi.set(__self__, "alertmanager_name", alertmanager_name)
        if alertmanager_status and not isinstance(alertmanager_status, str):
            raise TypeError("Expected argument 'alertmanager_status' to be a str")
        pulumi.set(__self__, "alertmanager_status", alertmanager_status)
        if alertmanager_url and not isinstance(alertmanager_url, str):
            raise TypeError("Expected argument 'alertmanager_url' to be a str")
        pulumi.set(__self__, "alertmanager_url", alertmanager_url)
        if alertmanager_user_id and not isinstance(alertmanager_user_id, int):
            raise TypeError("Expected argument 'alertmanager_user_id' to be a int")
        pulumi.set(__self__, "alertmanager_user_id", alertmanager_user_id)
        if cluster_slug and not isinstance(cluster_slug, str):
            raise TypeError("Expected argument 'cluster_slug' to be a str")
        pulumi.set(__self__, "cluster_slug", cluster_slug)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if fleet_management_name and not isinstance(fleet_management_name, str):
            raise TypeError("Expected argument 'fleet_management_name' to be a str")
        pulumi.set(__self__, "fleet_management_name", fleet_management_name)
        if fleet_management_status and not isinstance(fleet_management_status, str):
            raise TypeError("Expected argument 'fleet_management_status' to be a str")
        pulumi.set(__self__, "fleet_management_status", fleet_management_status)
        if fleet_management_url and not isinstance(fleet_management_url, str):
            raise TypeError("Expected argument 'fleet_management_url' to be a str")
        pulumi.set(__self__, "fleet_management_url", fleet_management_url)
        if fleet_management_user_id and not isinstance(fleet_management_user_id, int):
            raise TypeError("Expected argument 'fleet_management_user_id' to be a int")
        pulumi.set(__self__, "fleet_management_user_id", fleet_management_user_id)
        if grafanas_ip_allow_list_cname and not isinstance(grafanas_ip_allow_list_cname, str):
            raise TypeError("Expected argument 'grafanas_ip_allow_list_cname' to be a str")
        pulumi.set(__self__, "grafanas_ip_allow_list_cname", grafanas_ip_allow_list_cname)
        if graphite_ip_allow_list_cname and not isinstance(graphite_ip_allow_list_cname, str):
            raise TypeError("Expected argument 'graphite_ip_allow_list_cname' to be a str")
        pulumi.set(__self__, "graphite_ip_allow_list_cname", graphite_ip_allow_list_cname)
        if graphite_name and not isinstance(graphite_name, str):
            raise TypeError("Expected argument 'graphite_name' to be a str")
        pulumi.set(__self__, "graphite_name", graphite_name)
        if graphite_private_connectivity_info_private_dns and not isinstance(graphite_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'graphite_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "graphite_private_connectivity_info_private_dns", graphite_private_connectivity_info_private_dns)
        if graphite_private_connectivity_info_service_name and not isinstance(graphite_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'graphite_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "graphite_private_connectivity_info_service_name", graphite_private_connectivity_info_service_name)
        if graphite_status and not isinstance(graphite_status, str):
            raise TypeError("Expected argument 'graphite_status' to be a str")
        pulumi.set(__self__, "graphite_status", graphite_status)
        if graphite_url and not isinstance(graphite_url, str):
            raise TypeError("Expected argument 'graphite_url' to be a str")
        pulumi.set(__self__, "graphite_url", graphite_url)
        if graphite_user_id and not isinstance(graphite_user_id, int):
            raise TypeError("Expected argument 'graphite_user_id' to be a int")
        pulumi.set(__self__, "graphite_user_id", graphite_user_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if influx_url and not isinstance(influx_url, str):
            raise TypeError("Expected argument 'influx_url' to be a str")
        pulumi.set(__self__, "influx_url", influx_url)
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        pulumi.set(__self__, "labels", labels)
        if logs_ip_allow_list_cname and not isinstance(logs_ip_allow_list_cname, str):
            raise TypeError("Expected argument 'logs_ip_allow_list_cname' to be a str")
        pulumi.set(__self__, "logs_ip_allow_list_cname", logs_ip_allow_list_cname)
        if logs_name and not isinstance(logs_name, str):
            raise TypeError("Expected argument 'logs_name' to be a str")
        pulumi.set(__self__, "logs_name", logs_name)
        if logs_private_connectivity_info_private_dns and not isinstance(logs_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'logs_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "logs_private_connectivity_info_private_dns", logs_private_connectivity_info_private_dns)
        if logs_private_connectivity_info_service_name and not isinstance(logs_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'logs_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "logs_private_connectivity_info_service_name", logs_private_connectivity_info_service_name)
        if logs_status and not isinstance(logs_status, str):
            raise TypeError("Expected argument 'logs_status' to be a str")
        pulumi.set(__self__, "logs_status", logs_status)
        if logs_url and not isinstance(logs_url, str):
            raise TypeError("Expected argument 'logs_url' to be a str")
        pulumi.set(__self__, "logs_url", logs_url)
        if logs_user_id and not isinstance(logs_user_id, int):
            raise TypeError("Expected argument 'logs_user_id' to be a int")
        pulumi.set(__self__, "logs_user_id", logs_user_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, int):
            raise TypeError("Expected argument 'org_id' to be a int")
        pulumi.set(__self__, "org_id", org_id)
        if org_name and not isinstance(org_name, str):
            raise TypeError("Expected argument 'org_name' to be a str")
        pulumi.set(__self__, "org_name", org_name)
        if org_slug and not isinstance(org_slug, str):
            raise TypeError("Expected argument 'org_slug' to be a str")
        pulumi.set(__self__, "org_slug", org_slug)
        if otlp_private_connectivity_info_private_dns and not isinstance(otlp_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'otlp_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "otlp_private_connectivity_info_private_dns", otlp_private_connectivity_info_private_dns)
        if otlp_private_connectivity_info_service_name and not isinstance(otlp_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'otlp_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "otlp_private_connectivity_info_service_name", otlp_private_connectivity_info_service_name)
        if otlp_url and not isinstance(otlp_url, str):
            raise TypeError("Expected argument 'otlp_url' to be a str")
        pulumi.set(__self__, "otlp_url", otlp_url)
        if pdc_api_private_connectivity_info_private_dns and not isinstance(pdc_api_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'pdc_api_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "pdc_api_private_connectivity_info_private_dns", pdc_api_private_connectivity_info_private_dns)
        if pdc_api_private_connectivity_info_service_name and not isinstance(pdc_api_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'pdc_api_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "pdc_api_private_connectivity_info_service_name", pdc_api_private_connectivity_info_service_name)
        if pdc_gateway_private_connectivity_info_private_dns and not isinstance(pdc_gateway_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'pdc_gateway_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "pdc_gateway_private_connectivity_info_private_dns", pdc_gateway_private_connectivity_info_private_dns)
        if pdc_gateway_private_connectivity_info_service_name and not isinstance(pdc_gateway_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'pdc_gateway_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "pdc_gateway_private_connectivity_info_service_name", pdc_gateway_private_connectivity_info_service_name)
        if profiles_ip_allow_list_cname and not isinstance(profiles_ip_allow_list_cname, str):
            raise TypeError("Expected argument 'profiles_ip_allow_list_cname' to be a str")
        pulumi.set(__self__, "profiles_ip_allow_list_cname", profiles_ip_allow_list_cname)
        if profiles_name and not isinstance(profiles_name, str):
            raise TypeError("Expected argument 'profiles_name' to be a str")
        pulumi.set(__self__, "profiles_name", profiles_name)
        if profiles_private_connectivity_info_private_dns and not isinstance(profiles_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'profiles_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "profiles_private_connectivity_info_private_dns", profiles_private_connectivity_info_private_dns)
        if profiles_private_connectivity_info_service_name and not isinstance(profiles_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'profiles_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "profiles_private_connectivity_info_service_name", profiles_private_connectivity_info_service_name)
        if profiles_status and not isinstance(profiles_status, str):
            raise TypeError("Expected argument 'profiles_status' to be a str")
        pulumi.set(__self__, "profiles_status", profiles_status)
        if profiles_url and not isinstance(profiles_url, str):
            raise TypeError("Expected argument 'profiles_url' to be a str")
        pulumi.set(__self__, "profiles_url", profiles_url)
        if profiles_user_id and not isinstance(profiles_user_id, int):
            raise TypeError("Expected argument 'profiles_user_id' to be a int")
        pulumi.set(__self__, "profiles_user_id", profiles_user_id)
        if prometheus_ip_allow_list_cname and not isinstance(prometheus_ip_allow_list_cname, str):
            raise TypeError("Expected argument 'prometheus_ip_allow_list_cname' to be a str")
        pulumi.set(__self__, "prometheus_ip_allow_list_cname", prometheus_ip_allow_list_cname)
        if prometheus_name and not isinstance(prometheus_name, str):
            raise TypeError("Expected argument 'prometheus_name' to be a str")
        pulumi.set(__self__, "prometheus_name", prometheus_name)
        if prometheus_private_connectivity_info_private_dns and not isinstance(prometheus_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'prometheus_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "prometheus_private_connectivity_info_private_dns", prometheus_private_connectivity_info_private_dns)
        if prometheus_private_connectivity_info_service_name and not isinstance(prometheus_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'prometheus_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "prometheus_private_connectivity_info_service_name", prometheus_private_connectivity_info_service_name)
        if prometheus_remote_endpoint and not isinstance(prometheus_remote_endpoint, str):
            raise TypeError("Expected argument 'prometheus_remote_endpoint' to be a str")
        pulumi.set(__self__, "prometheus_remote_endpoint", prometheus_remote_endpoint)
        if prometheus_remote_write_endpoint and not isinstance(prometheus_remote_write_endpoint, str):
            raise TypeError("Expected argument 'prometheus_remote_write_endpoint' to be a str")
        pulumi.set(__self__, "prometheus_remote_write_endpoint", prometheus_remote_write_endpoint)
        if prometheus_status and not isinstance(prometheus_status, str):
            raise TypeError("Expected argument 'prometheus_status' to be a str")
        pulumi.set(__self__, "prometheus_status", prometheus_status)
        if prometheus_url and not isinstance(prometheus_url, str):
            raise TypeError("Expected argument 'prometheus_url' to be a str")
        pulumi.set(__self__, "prometheus_url", prometheus_url)
        if prometheus_user_id and not isinstance(prometheus_user_id, int):
            raise TypeError("Expected argument 'prometheus_user_id' to be a int")
        pulumi.set(__self__, "prometheus_user_id", prometheus_user_id)
        if region_slug and not isinstance(region_slug, str):
            raise TypeError("Expected argument 'region_slug' to be a str")
        pulumi.set(__self__, "region_slug", region_slug)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if traces_ip_allow_list_cname and not isinstance(traces_ip_allow_list_cname, str):
            raise TypeError("Expected argument 'traces_ip_allow_list_cname' to be a str")
        pulumi.set(__self__, "traces_ip_allow_list_cname", traces_ip_allow_list_cname)
        if traces_name and not isinstance(traces_name, str):
            raise TypeError("Expected argument 'traces_name' to be a str")
        pulumi.set(__self__, "traces_name", traces_name)
        if traces_private_connectivity_info_private_dns and not isinstance(traces_private_connectivity_info_private_dns, str):
            raise TypeError("Expected argument 'traces_private_connectivity_info_private_dns' to be a str")
        pulumi.set(__self__, "traces_private_connectivity_info_private_dns", traces_private_connectivity_info_private_dns)
        if traces_private_connectivity_info_service_name and not isinstance(traces_private_connectivity_info_service_name, str):
            raise TypeError("Expected argument 'traces_private_connectivity_info_service_name' to be a str")
        pulumi.set(__self__, "traces_private_connectivity_info_service_name", traces_private_connectivity_info_service_name)
        if traces_status and not isinstance(traces_status, str):
            raise TypeError("Expected argument 'traces_status' to be a str")
        pulumi.set(__self__, "traces_status", traces_status)
        if traces_url and not isinstance(traces_url, str):
            raise TypeError("Expected argument 'traces_url' to be a str")
        pulumi.set(__self__, "traces_url", traces_url)
        if traces_user_id and not isinstance(traces_user_id, int):
            raise TypeError("Expected argument 'traces_user_id' to be a int")
        pulumi.set(__self__, "traces_user_id", traces_user_id)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="alertmanagerIpAllowListCname")
    def alertmanager_ip_allow_list_cname(self) -> str:
        """
        Comma-separated list of CNAMEs that can be whitelisted to access the Alertmanager instances (Optional)
        """
        return pulumi.get(self, "alertmanager_ip_allow_list_cname")

    @property
    @pulumi.getter(name="alertmanagerName")
    def alertmanager_name(self) -> str:
        """
        Name of the Alertmanager instance configured for this stack.
        """
        return pulumi.get(self, "alertmanager_name")

    @property
    @pulumi.getter(name="alertmanagerStatus")
    def alertmanager_status(self) -> str:
        """
        Status of the Alertmanager instance configured for this stack.
        """
        return pulumi.get(self, "alertmanager_status")

    @property
    @pulumi.getter(name="alertmanagerUrl")
    def alertmanager_url(self) -> str:
        """
        Base URL of the Alertmanager instance configured for this stack.
        """
        return pulumi.get(self, "alertmanager_url")

    @property
    @pulumi.getter(name="alertmanagerUserId")
    def alertmanager_user_id(self) -> int:
        """
        User ID of the Alertmanager instance configured for this stack.
        """
        return pulumi.get(self, "alertmanager_user_id")

    @property
    @pulumi.getter(name="clusterSlug")
    def cluster_slug(self) -> str:
        """
        Slug of the cluster where this stack resides.
        """
        return pulumi.get(self, "cluster_slug")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of stack.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fleetManagementName")
    def fleet_management_name(self) -> str:
        """
        Name of the Fleet Management instance configured for this stack.
        """
        return pulumi.get(self, "fleet_management_name")

    @property
    @pulumi.getter(name="fleetManagementStatus")
    def fleet_management_status(self) -> str:
        """
        Status of the Fleet Management instance configured for this stack.
        """
        return pulumi.get(self, "fleet_management_status")

    @property
    @pulumi.getter(name="fleetManagementUrl")
    def fleet_management_url(self) -> str:
        """
        Base URL of the Fleet Management instance configured for this stack.
        """
        return pulumi.get(self, "fleet_management_url")

    @property
    @pulumi.getter(name="fleetManagementUserId")
    def fleet_management_user_id(self) -> int:
        """
        User ID of the Fleet Management instance configured for this stack.
        """
        return pulumi.get(self, "fleet_management_user_id")

    @property
    @pulumi.getter(name="grafanasIpAllowListCname")
    def grafanas_ip_allow_list_cname(self) -> str:
        """
        Comma-separated list of CNAMEs that can be whitelisted to access the grafana instance (Optional)
        """
        return pulumi.get(self, "grafanas_ip_allow_list_cname")

    @property
    @pulumi.getter(name="graphiteIpAllowListCname")
    def graphite_ip_allow_list_cname(self) -> str:
        """
        Comma-separated list of CNAMEs that can be whitelisted to access the Graphite instance (Optional)
        """
        return pulumi.get(self, "graphite_ip_allow_list_cname")

    @property
    @pulumi.getter(name="graphiteName")
    def graphite_name(self) -> str:
        return pulumi.get(self, "graphite_name")

    @property
    @pulumi.getter(name="graphitePrivateConnectivityInfoPrivateDns")
    def graphite_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for Graphite when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "graphite_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="graphitePrivateConnectivityInfoServiceName")
    def graphite_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for Graphite when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "graphite_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="graphiteStatus")
    def graphite_status(self) -> str:
        return pulumi.get(self, "graphite_status")

    @property
    @pulumi.getter(name="graphiteUrl")
    def graphite_url(self) -> str:
        return pulumi.get(self, "graphite_url")

    @property
    @pulumi.getter(name="graphiteUserId")
    def graphite_user_id(self) -> int:
        return pulumi.get(self, "graphite_user_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The stack id assigned to this stack by Grafana.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="influxUrl")
    def influx_url(self) -> str:
        """
        Base URL of the InfluxDB instance configured for this stack. The username is the same as the metrics' (`prometheus_user_id` attribute of this resource). See https://grafana.com/docs/grafana-cloud/send-data/metrics/metrics-influxdb/push-from-telegraf/ for docs on how to use this.
        """
        return pulumi.get(self, "influx_url")

    @property
    @pulumi.getter
    def labels(self) -> Mapping[str, str]:
        """
        A map of labels to assign to the stack. Label keys and values must match the following regexp: "^[a-zA-Z0-9/\\-.]+$" and stacks cannot have more than 10 labels.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter(name="logsIpAllowListCname")
    def logs_ip_allow_list_cname(self) -> str:
        """
        Comma-separated list of CNAMEs that can be whitelisted to access the Logs instance (Optional)
        """
        return pulumi.get(self, "logs_ip_allow_list_cname")

    @property
    @pulumi.getter(name="logsName")
    def logs_name(self) -> str:
        return pulumi.get(self, "logs_name")

    @property
    @pulumi.getter(name="logsPrivateConnectivityInfoPrivateDns")
    def logs_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for Logs when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "logs_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="logsPrivateConnectivityInfoServiceName")
    def logs_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for Logs when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "logs_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="logsStatus")
    def logs_status(self) -> str:
        return pulumi.get(self, "logs_status")

    @property
    @pulumi.getter(name="logsUrl")
    def logs_url(self) -> str:
        return pulumi.get(self, "logs_url")

    @property
    @pulumi.getter(name="logsUserId")
    def logs_user_id(self) -> int:
        return pulumi.get(self, "logs_user_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of stack. Conventionally matches the url of the instance (e.g. `<stack_slug>.grafana.net`).
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> int:
        """
        Organization id to assign to this stack.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="orgName")
    def org_name(self) -> str:
        """
        Organization name to assign to this stack.
        """
        return pulumi.get(self, "org_name")

    @property
    @pulumi.getter(name="orgSlug")
    def org_slug(self) -> str:
        """
        Organization slug to assign to this stack.
        """
        return pulumi.get(self, "org_slug")

    @property
    @pulumi.getter(name="otlpPrivateConnectivityInfoPrivateDns")
    def otlp_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for OTLP when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "otlp_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="otlpPrivateConnectivityInfoServiceName")
    def otlp_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for OTLP when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "otlp_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="otlpUrl")
    def otlp_url(self) -> str:
        """
        Base URL of the OTLP instance configured for this stack. The username is the stack's ID (`id` attribute of this resource). See https://grafana.com/docs/grafana-cloud/send-data/otlp/send-data-otlp/ for docs on how to use this.
        """
        return pulumi.get(self, "otlp_url")

    @property
    @pulumi.getter(name="pdcApiPrivateConnectivityInfoPrivateDns")
    def pdc_api_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for PDC's API when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "pdc_api_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="pdcApiPrivateConnectivityInfoServiceName")
    def pdc_api_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for PDC's API when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "pdc_api_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="pdcGatewayPrivateConnectivityInfoPrivateDns")
    def pdc_gateway_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for PDC's Gateway when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "pdc_gateway_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="pdcGatewayPrivateConnectivityInfoServiceName")
    def pdc_gateway_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for PDC's Gateway when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "pdc_gateway_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="profilesIpAllowListCname")
    def profiles_ip_allow_list_cname(self) -> str:
        """
        Comma-separated list of CNAMEs that can be whitelisted to access the Profiles instance (Optional)
        """
        return pulumi.get(self, "profiles_ip_allow_list_cname")

    @property
    @pulumi.getter(name="profilesName")
    def profiles_name(self) -> str:
        return pulumi.get(self, "profiles_name")

    @property
    @pulumi.getter(name="profilesPrivateConnectivityInfoPrivateDns")
    def profiles_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for Profiles when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "profiles_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="profilesPrivateConnectivityInfoServiceName")
    def profiles_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for Profiles when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "profiles_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="profilesStatus")
    def profiles_status(self) -> str:
        return pulumi.get(self, "profiles_status")

    @property
    @pulumi.getter(name="profilesUrl")
    def profiles_url(self) -> str:
        return pulumi.get(self, "profiles_url")

    @property
    @pulumi.getter(name="profilesUserId")
    def profiles_user_id(self) -> int:
        return pulumi.get(self, "profiles_user_id")

    @property
    @pulumi.getter(name="prometheusIpAllowListCname")
    def prometheus_ip_allow_list_cname(self) -> str:
        """
        Comma-separated list of CNAMEs that can be whitelisted to access the Prometheus instance (Optional)
        """
        return pulumi.get(self, "prometheus_ip_allow_list_cname")

    @property
    @pulumi.getter(name="prometheusName")
    def prometheus_name(self) -> str:
        """
        Prometheus name for this instance.
        """
        return pulumi.get(self, "prometheus_name")

    @property
    @pulumi.getter(name="prometheusPrivateConnectivityInfoPrivateDns")
    def prometheus_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for Prometheus when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "prometheus_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="prometheusPrivateConnectivityInfoServiceName")
    def prometheus_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for Prometheus when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "prometheus_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="prometheusRemoteEndpoint")
    def prometheus_remote_endpoint(self) -> str:
        """
        Use this URL to query hosted metrics data e.g. Prometheus data source in Grafana
        """
        return pulumi.get(self, "prometheus_remote_endpoint")

    @property
    @pulumi.getter(name="prometheusRemoteWriteEndpoint")
    def prometheus_remote_write_endpoint(self) -> str:
        """
        Use this URL to send prometheus metrics to Grafana cloud
        """
        return pulumi.get(self, "prometheus_remote_write_endpoint")

    @property
    @pulumi.getter(name="prometheusStatus")
    def prometheus_status(self) -> str:
        """
        Prometheus status for this instance.
        """
        return pulumi.get(self, "prometheus_status")

    @property
    @pulumi.getter(name="prometheusUrl")
    def prometheus_url(self) -> str:
        """
        Prometheus url for this instance.
        """
        return pulumi.get(self, "prometheus_url")

    @property
    @pulumi.getter(name="prometheusUserId")
    def prometheus_user_id(self) -> int:
        """
        Prometheus user ID. Used for e.g. remote_write.
        """
        return pulumi.get(self, "prometheus_user_id")

    @property
    @pulumi.getter(name="regionSlug")
    def region_slug(self) -> str:
        """
        The region this stack is deployed to.
        """
        return pulumi.get(self, "region_slug")

    @property
    @pulumi.getter
    def slug(self) -> str:
        """
        Subdomain that the Grafana instance will be available at (i.e. setting slug to “\\n\\n” will make the instance
        available at “https://\\n\\n.grafana.net".
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Status of the stack.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="tracesIpAllowListCname")
    def traces_ip_allow_list_cname(self) -> str:
        """
        Comma-separated list of CNAMEs that can be whitelisted to access the Traces instance (Optional)
        """
        return pulumi.get(self, "traces_ip_allow_list_cname")

    @property
    @pulumi.getter(name="tracesName")
    def traces_name(self) -> str:
        return pulumi.get(self, "traces_name")

    @property
    @pulumi.getter(name="tracesPrivateConnectivityInfoPrivateDns")
    def traces_private_connectivity_info_private_dns(self) -> str:
        """
        Private DNS for Traces when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "traces_private_connectivity_info_private_dns")

    @property
    @pulumi.getter(name="tracesPrivateConnectivityInfoServiceName")
    def traces_private_connectivity_info_service_name(self) -> str:
        """
        Service Name for Traces when using AWS PrivateLink (only for AWS stacks)
        """
        return pulumi.get(self, "traces_private_connectivity_info_service_name")

    @property
    @pulumi.getter(name="tracesStatus")
    def traces_status(self) -> str:
        return pulumi.get(self, "traces_status")

    @property
    @pulumi.getter(name="tracesUrl")
    def traces_url(self) -> str:
        """
        Base URL of the Traces instance configured for this stack. To use this in the Tempo data source in Grafana, append `/tempo` to the URL.
        """
        return pulumi.get(self, "traces_url")

    @property
    @pulumi.getter(name="tracesUserId")
    def traces_user_id(self) -> int:
        return pulumi.get(self, "traces_user_id")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        Custom URL for the Grafana instance. Must have a CNAME setup to point to `.grafana.net` before creating the stack
        """
        return pulumi.get(self, "url")


class AwaitableGetStackResult(GetStackResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStackResult(
            alertmanager_ip_allow_list_cname=self.alertmanager_ip_allow_list_cname,
            alertmanager_name=self.alertmanager_name,
            alertmanager_status=self.alertmanager_status,
            alertmanager_url=self.alertmanager_url,
            alertmanager_user_id=self.alertmanager_user_id,
            cluster_slug=self.cluster_slug,
            description=self.description,
            fleet_management_name=self.fleet_management_name,
            fleet_management_status=self.fleet_management_status,
            fleet_management_url=self.fleet_management_url,
            fleet_management_user_id=self.fleet_management_user_id,
            grafanas_ip_allow_list_cname=self.grafanas_ip_allow_list_cname,
            graphite_ip_allow_list_cname=self.graphite_ip_allow_list_cname,
            graphite_name=self.graphite_name,
            graphite_private_connectivity_info_private_dns=self.graphite_private_connectivity_info_private_dns,
            graphite_private_connectivity_info_service_name=self.graphite_private_connectivity_info_service_name,
            graphite_status=self.graphite_status,
            graphite_url=self.graphite_url,
            graphite_user_id=self.graphite_user_id,
            id=self.id,
            influx_url=self.influx_url,
            labels=self.labels,
            logs_ip_allow_list_cname=self.logs_ip_allow_list_cname,
            logs_name=self.logs_name,
            logs_private_connectivity_info_private_dns=self.logs_private_connectivity_info_private_dns,
            logs_private_connectivity_info_service_name=self.logs_private_connectivity_info_service_name,
            logs_status=self.logs_status,
            logs_url=self.logs_url,
            logs_user_id=self.logs_user_id,
            name=self.name,
            org_id=self.org_id,
            org_name=self.org_name,
            org_slug=self.org_slug,
            otlp_private_connectivity_info_private_dns=self.otlp_private_connectivity_info_private_dns,
            otlp_private_connectivity_info_service_name=self.otlp_private_connectivity_info_service_name,
            otlp_url=self.otlp_url,
            pdc_api_private_connectivity_info_private_dns=self.pdc_api_private_connectivity_info_private_dns,
            pdc_api_private_connectivity_info_service_name=self.pdc_api_private_connectivity_info_service_name,
            pdc_gateway_private_connectivity_info_private_dns=self.pdc_gateway_private_connectivity_info_private_dns,
            pdc_gateway_private_connectivity_info_service_name=self.pdc_gateway_private_connectivity_info_service_name,
            profiles_ip_allow_list_cname=self.profiles_ip_allow_list_cname,
            profiles_name=self.profiles_name,
            profiles_private_connectivity_info_private_dns=self.profiles_private_connectivity_info_private_dns,
            profiles_private_connectivity_info_service_name=self.profiles_private_connectivity_info_service_name,
            profiles_status=self.profiles_status,
            profiles_url=self.profiles_url,
            profiles_user_id=self.profiles_user_id,
            prometheus_ip_allow_list_cname=self.prometheus_ip_allow_list_cname,
            prometheus_name=self.prometheus_name,
            prometheus_private_connectivity_info_private_dns=self.prometheus_private_connectivity_info_private_dns,
            prometheus_private_connectivity_info_service_name=self.prometheus_private_connectivity_info_service_name,
            prometheus_remote_endpoint=self.prometheus_remote_endpoint,
            prometheus_remote_write_endpoint=self.prometheus_remote_write_endpoint,
            prometheus_status=self.prometheus_status,
            prometheus_url=self.prometheus_url,
            prometheus_user_id=self.prometheus_user_id,
            region_slug=self.region_slug,
            slug=self.slug,
            status=self.status,
            traces_ip_allow_list_cname=self.traces_ip_allow_list_cname,
            traces_name=self.traces_name,
            traces_private_connectivity_info_private_dns=self.traces_private_connectivity_info_private_dns,
            traces_private_connectivity_info_service_name=self.traces_private_connectivity_info_service_name,
            traces_status=self.traces_status,
            traces_url=self.traces_url,
            traces_user_id=self.traces_user_id,
            url=self.url)


def get_stack(slug: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStackResult:
    """
    Data source for Grafana Stack

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test_stack = grafana.cloud.Stack("test",
        name="gcloudstacktest",
        slug="gcloudstacktest",
        region_slug="eu",
        description="Test Grafana Cloud Stack")
    test = grafana.cloud.get_stack_output(slug=test_stack.slug)
    ```


    :param str slug: Subdomain that the Grafana instance will be available at (i.e. setting slug to “\\n\\n” will make the instance
           available at “https://\\n\\n.grafana.net".
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:cloud/getStack:getStack', __args__, opts=opts, typ=GetStackResult).value

    return AwaitableGetStackResult(
        alertmanager_ip_allow_list_cname=pulumi.get(__ret__, 'alertmanager_ip_allow_list_cname'),
        alertmanager_name=pulumi.get(__ret__, 'alertmanager_name'),
        alertmanager_status=pulumi.get(__ret__, 'alertmanager_status'),
        alertmanager_url=pulumi.get(__ret__, 'alertmanager_url'),
        alertmanager_user_id=pulumi.get(__ret__, 'alertmanager_user_id'),
        cluster_slug=pulumi.get(__ret__, 'cluster_slug'),
        description=pulumi.get(__ret__, 'description'),
        fleet_management_name=pulumi.get(__ret__, 'fleet_management_name'),
        fleet_management_status=pulumi.get(__ret__, 'fleet_management_status'),
        fleet_management_url=pulumi.get(__ret__, 'fleet_management_url'),
        fleet_management_user_id=pulumi.get(__ret__, 'fleet_management_user_id'),
        grafanas_ip_allow_list_cname=pulumi.get(__ret__, 'grafanas_ip_allow_list_cname'),
        graphite_ip_allow_list_cname=pulumi.get(__ret__, 'graphite_ip_allow_list_cname'),
        graphite_name=pulumi.get(__ret__, 'graphite_name'),
        graphite_private_connectivity_info_private_dns=pulumi.get(__ret__, 'graphite_private_connectivity_info_private_dns'),
        graphite_private_connectivity_info_service_name=pulumi.get(__ret__, 'graphite_private_connectivity_info_service_name'),
        graphite_status=pulumi.get(__ret__, 'graphite_status'),
        graphite_url=pulumi.get(__ret__, 'graphite_url'),
        graphite_user_id=pulumi.get(__ret__, 'graphite_user_id'),
        id=pulumi.get(__ret__, 'id'),
        influx_url=pulumi.get(__ret__, 'influx_url'),
        labels=pulumi.get(__ret__, 'labels'),
        logs_ip_allow_list_cname=pulumi.get(__ret__, 'logs_ip_allow_list_cname'),
        logs_name=pulumi.get(__ret__, 'logs_name'),
        logs_private_connectivity_info_private_dns=pulumi.get(__ret__, 'logs_private_connectivity_info_private_dns'),
        logs_private_connectivity_info_service_name=pulumi.get(__ret__, 'logs_private_connectivity_info_service_name'),
        logs_status=pulumi.get(__ret__, 'logs_status'),
        logs_url=pulumi.get(__ret__, 'logs_url'),
        logs_user_id=pulumi.get(__ret__, 'logs_user_id'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        org_name=pulumi.get(__ret__, 'org_name'),
        org_slug=pulumi.get(__ret__, 'org_slug'),
        otlp_private_connectivity_info_private_dns=pulumi.get(__ret__, 'otlp_private_connectivity_info_private_dns'),
        otlp_private_connectivity_info_service_name=pulumi.get(__ret__, 'otlp_private_connectivity_info_service_name'),
        otlp_url=pulumi.get(__ret__, 'otlp_url'),
        pdc_api_private_connectivity_info_private_dns=pulumi.get(__ret__, 'pdc_api_private_connectivity_info_private_dns'),
        pdc_api_private_connectivity_info_service_name=pulumi.get(__ret__, 'pdc_api_private_connectivity_info_service_name'),
        pdc_gateway_private_connectivity_info_private_dns=pulumi.get(__ret__, 'pdc_gateway_private_connectivity_info_private_dns'),
        pdc_gateway_private_connectivity_info_service_name=pulumi.get(__ret__, 'pdc_gateway_private_connectivity_info_service_name'),
        profiles_ip_allow_list_cname=pulumi.get(__ret__, 'profiles_ip_allow_list_cname'),
        profiles_name=pulumi.get(__ret__, 'profiles_name'),
        profiles_private_connectivity_info_private_dns=pulumi.get(__ret__, 'profiles_private_connectivity_info_private_dns'),
        profiles_private_connectivity_info_service_name=pulumi.get(__ret__, 'profiles_private_connectivity_info_service_name'),
        profiles_status=pulumi.get(__ret__, 'profiles_status'),
        profiles_url=pulumi.get(__ret__, 'profiles_url'),
        profiles_user_id=pulumi.get(__ret__, 'profiles_user_id'),
        prometheus_ip_allow_list_cname=pulumi.get(__ret__, 'prometheus_ip_allow_list_cname'),
        prometheus_name=pulumi.get(__ret__, 'prometheus_name'),
        prometheus_private_connectivity_info_private_dns=pulumi.get(__ret__, 'prometheus_private_connectivity_info_private_dns'),
        prometheus_private_connectivity_info_service_name=pulumi.get(__ret__, 'prometheus_private_connectivity_info_service_name'),
        prometheus_remote_endpoint=pulumi.get(__ret__, 'prometheus_remote_endpoint'),
        prometheus_remote_write_endpoint=pulumi.get(__ret__, 'prometheus_remote_write_endpoint'),
        prometheus_status=pulumi.get(__ret__, 'prometheus_status'),
        prometheus_url=pulumi.get(__ret__, 'prometheus_url'),
        prometheus_user_id=pulumi.get(__ret__, 'prometheus_user_id'),
        region_slug=pulumi.get(__ret__, 'region_slug'),
        slug=pulumi.get(__ret__, 'slug'),
        status=pulumi.get(__ret__, 'status'),
        traces_ip_allow_list_cname=pulumi.get(__ret__, 'traces_ip_allow_list_cname'),
        traces_name=pulumi.get(__ret__, 'traces_name'),
        traces_private_connectivity_info_private_dns=pulumi.get(__ret__, 'traces_private_connectivity_info_private_dns'),
        traces_private_connectivity_info_service_name=pulumi.get(__ret__, 'traces_private_connectivity_info_service_name'),
        traces_status=pulumi.get(__ret__, 'traces_status'),
        traces_url=pulumi.get(__ret__, 'traces_url'),
        traces_user_id=pulumi.get(__ret__, 'traces_user_id'),
        url=pulumi.get(__ret__, 'url'))
def get_stack_output(slug: Optional[pulumi.Input[str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetStackResult]:
    """
    Data source for Grafana Stack

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test_stack = grafana.cloud.Stack("test",
        name="gcloudstacktest",
        slug="gcloudstacktest",
        region_slug="eu",
        description="Test Grafana Cloud Stack")
    test = grafana.cloud.get_stack_output(slug=test_stack.slug)
    ```


    :param str slug: Subdomain that the Grafana instance will be available at (i.e. setting slug to “\\n\\n” will make the instance
           available at “https://\\n\\n.grafana.net".
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:cloud/getStack:getStack', __args__, opts=opts, typ=GetStackResult)
    return __ret__.apply(lambda __response__: GetStackResult(
        alertmanager_ip_allow_list_cname=pulumi.get(__response__, 'alertmanager_ip_allow_list_cname'),
        alertmanager_name=pulumi.get(__response__, 'alertmanager_name'),
        alertmanager_status=pulumi.get(__response__, 'alertmanager_status'),
        alertmanager_url=pulumi.get(__response__, 'alertmanager_url'),
        alertmanager_user_id=pulumi.get(__response__, 'alertmanager_user_id'),
        cluster_slug=pulumi.get(__response__, 'cluster_slug'),
        description=pulumi.get(__response__, 'description'),
        fleet_management_name=pulumi.get(__response__, 'fleet_management_name'),
        fleet_management_status=pulumi.get(__response__, 'fleet_management_status'),
        fleet_management_url=pulumi.get(__response__, 'fleet_management_url'),
        fleet_management_user_id=pulumi.get(__response__, 'fleet_management_user_id'),
        grafanas_ip_allow_list_cname=pulumi.get(__response__, 'grafanas_ip_allow_list_cname'),
        graphite_ip_allow_list_cname=pulumi.get(__response__, 'graphite_ip_allow_list_cname'),
        graphite_name=pulumi.get(__response__, 'graphite_name'),
        graphite_private_connectivity_info_private_dns=pulumi.get(__response__, 'graphite_private_connectivity_info_private_dns'),
        graphite_private_connectivity_info_service_name=pulumi.get(__response__, 'graphite_private_connectivity_info_service_name'),
        graphite_status=pulumi.get(__response__, 'graphite_status'),
        graphite_url=pulumi.get(__response__, 'graphite_url'),
        graphite_user_id=pulumi.get(__response__, 'graphite_user_id'),
        id=pulumi.get(__response__, 'id'),
        influx_url=pulumi.get(__response__, 'influx_url'),
        labels=pulumi.get(__response__, 'labels'),
        logs_ip_allow_list_cname=pulumi.get(__response__, 'logs_ip_allow_list_cname'),
        logs_name=pulumi.get(__response__, 'logs_name'),
        logs_private_connectivity_info_private_dns=pulumi.get(__response__, 'logs_private_connectivity_info_private_dns'),
        logs_private_connectivity_info_service_name=pulumi.get(__response__, 'logs_private_connectivity_info_service_name'),
        logs_status=pulumi.get(__response__, 'logs_status'),
        logs_url=pulumi.get(__response__, 'logs_url'),
        logs_user_id=pulumi.get(__response__, 'logs_user_id'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        org_name=pulumi.get(__response__, 'org_name'),
        org_slug=pulumi.get(__response__, 'org_slug'),
        otlp_private_connectivity_info_private_dns=pulumi.get(__response__, 'otlp_private_connectivity_info_private_dns'),
        otlp_private_connectivity_info_service_name=pulumi.get(__response__, 'otlp_private_connectivity_info_service_name'),
        otlp_url=pulumi.get(__response__, 'otlp_url'),
        pdc_api_private_connectivity_info_private_dns=pulumi.get(__response__, 'pdc_api_private_connectivity_info_private_dns'),
        pdc_api_private_connectivity_info_service_name=pulumi.get(__response__, 'pdc_api_private_connectivity_info_service_name'),
        pdc_gateway_private_connectivity_info_private_dns=pulumi.get(__response__, 'pdc_gateway_private_connectivity_info_private_dns'),
        pdc_gateway_private_connectivity_info_service_name=pulumi.get(__response__, 'pdc_gateway_private_connectivity_info_service_name'),
        profiles_ip_allow_list_cname=pulumi.get(__response__, 'profiles_ip_allow_list_cname'),
        profiles_name=pulumi.get(__response__, 'profiles_name'),
        profiles_private_connectivity_info_private_dns=pulumi.get(__response__, 'profiles_private_connectivity_info_private_dns'),
        profiles_private_connectivity_info_service_name=pulumi.get(__response__, 'profiles_private_connectivity_info_service_name'),
        profiles_status=pulumi.get(__response__, 'profiles_status'),
        profiles_url=pulumi.get(__response__, 'profiles_url'),
        profiles_user_id=pulumi.get(__response__, 'profiles_user_id'),
        prometheus_ip_allow_list_cname=pulumi.get(__response__, 'prometheus_ip_allow_list_cname'),
        prometheus_name=pulumi.get(__response__, 'prometheus_name'),
        prometheus_private_connectivity_info_private_dns=pulumi.get(__response__, 'prometheus_private_connectivity_info_private_dns'),
        prometheus_private_connectivity_info_service_name=pulumi.get(__response__, 'prometheus_private_connectivity_info_service_name'),
        prometheus_remote_endpoint=pulumi.get(__response__, 'prometheus_remote_endpoint'),
        prometheus_remote_write_endpoint=pulumi.get(__response__, 'prometheus_remote_write_endpoint'),
        prometheus_status=pulumi.get(__response__, 'prometheus_status'),
        prometheus_url=pulumi.get(__response__, 'prometheus_url'),
        prometheus_user_id=pulumi.get(__response__, 'prometheus_user_id'),
        region_slug=pulumi.get(__response__, 'region_slug'),
        slug=pulumi.get(__response__, 'slug'),
        status=pulumi.get(__response__, 'status'),
        traces_ip_allow_list_cname=pulumi.get(__response__, 'traces_ip_allow_list_cname'),
        traces_name=pulumi.get(__response__, 'traces_name'),
        traces_private_connectivity_info_private_dns=pulumi.get(__response__, 'traces_private_connectivity_info_private_dns'),
        traces_private_connectivity_info_service_name=pulumi.get(__response__, 'traces_private_connectivity_info_service_name'),
        traces_status=pulumi.get(__response__, 'traces_status'),
        traces_url=pulumi.get(__response__, 'traces_url'),
        traces_user_id=pulumi.get(__response__, 'traces_user_id'),
        url=pulumi.get(__response__, 'url')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RoleAssignmentArgs', 'RoleAssignment']

@pulumi.input_type
class RoleAssignmentArgs:
    def __init__(__self__, *,
                 role_uid: pulumi.Input[str],
                 org_id: Optional[pulumi.Input[str]] = None,
                 service_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None):
        """
        The set of arguments for constructing a RoleAssignment resource.
        :param pulumi.Input[str] role_uid: Grafana RBAC role UID.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] service_accounts: IDs of service accounts that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: IDs of teams that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] users: IDs of users that the role should be assigned to.
        """
        pulumi.set(__self__, "role_uid", role_uid)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if service_accounts is not None:
            pulumi.set(__self__, "service_accounts", service_accounts)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="roleUid")
    def role_uid(self) -> pulumi.Input[str]:
        """
        Grafana RBAC role UID.
        """
        return pulumi.get(self, "role_uid")

    @role_uid.setter
    def role_uid(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_uid", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="serviceAccounts")
    def service_accounts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        IDs of service accounts that the role should be assigned to.
        """
        return pulumi.get(self, "service_accounts")

    @service_accounts.setter
    def service_accounts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "service_accounts", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        IDs of teams that the role should be assigned to.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "teams", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        IDs of users that the role should be assigned to.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "users", value)


@pulumi.input_type
class _RoleAssignmentState:
    def __init__(__self__, *,
                 org_id: Optional[pulumi.Input[str]] = None,
                 role_uid: Optional[pulumi.Input[str]] = None,
                 service_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None):
        """
        Input properties used for looking up and filtering RoleAssignment resources.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] role_uid: Grafana RBAC role UID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] service_accounts: IDs of service accounts that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: IDs of teams that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] users: IDs of users that the role should be assigned to.
        """
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if role_uid is not None:
            pulumi.set(__self__, "role_uid", role_uid)
        if service_accounts is not None:
            pulumi.set(__self__, "service_accounts", service_accounts)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="roleUid")
    def role_uid(self) -> Optional[pulumi.Input[str]]:
        """
        Grafana RBAC role UID.
        """
        return pulumi.get(self, "role_uid")

    @role_uid.setter
    def role_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_uid", value)

    @property
    @pulumi.getter(name="serviceAccounts")
    def service_accounts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        IDs of service accounts that the role should be assigned to.
        """
        return pulumi.get(self, "service_accounts")

    @service_accounts.setter
    def service_accounts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "service_accounts", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        IDs of teams that the role should be assigned to.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "teams", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        IDs of users that the role should be assigned to.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "users", value)


class RoleAssignment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 role_uid: Optional[pulumi.Input[str]] = None,
                 service_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 __props__=None):
        """
        Manages the entire set of assignments for a role. Assignments that aren't specified when applying this resource will be removed.
        **Note:** This resource is available only with Grafana Enterprise 9.2+.
        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/roles-and-permissions/access-control/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/access_control/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_role = grafana.enterprise.Role("test_role",
            name="Test Role",
            uid="testrole",
            version=1,
            global_=True,
            permissions=[{
                "action": "org.users:add",
                "scope": "users:*",
            }])
        test_team = grafana.oss.Team("test_team", name="terraform_test_team")
        test_user = grafana.oss.User("test_user",
            email="terraform_user@test.com",
            login="terraform_user@test.com",
            password="password")
        test_sa = grafana.oss.ServiceAccount("test_sa",
            name="terraform_test_sa",
            role="Viewer")
        test = grafana.enterprise.RoleAssignment("test",
            role_uid=test_role.uid,
            users=[test_user.id],
            teams=[test_team.id],
            service_accounts=[test_sa.id])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:enterprise/roleAssignment:RoleAssignment name "{{ roleUID }}"
        ```

        ```sh
        $ pulumi import grafana:enterprise/roleAssignment:RoleAssignment name "{{ orgID }}:{{ roleUID }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] role_uid: Grafana RBAC role UID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] service_accounts: IDs of service accounts that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: IDs of teams that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] users: IDs of users that the role should be assigned to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleAssignmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the entire set of assignments for a role. Assignments that aren't specified when applying this resource will be removed.
        **Note:** This resource is available only with Grafana Enterprise 9.2+.
        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/roles-and-permissions/access-control/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/access_control/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_role = grafana.enterprise.Role("test_role",
            name="Test Role",
            uid="testrole",
            version=1,
            global_=True,
            permissions=[{
                "action": "org.users:add",
                "scope": "users:*",
            }])
        test_team = grafana.oss.Team("test_team", name="terraform_test_team")
        test_user = grafana.oss.User("test_user",
            email="terraform_user@test.com",
            login="terraform_user@test.com",
            password="password")
        test_sa = grafana.oss.ServiceAccount("test_sa",
            name="terraform_test_sa",
            role="Viewer")
        test = grafana.enterprise.RoleAssignment("test",
            role_uid=test_role.uid,
            users=[test_user.id],
            teams=[test_team.id],
            service_accounts=[test_sa.id])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:enterprise/roleAssignment:RoleAssignment name "{{ roleUID }}"
        ```

        ```sh
        $ pulumi import grafana:enterprise/roleAssignment:RoleAssignment name "{{ orgID }}:{{ roleUID }}"
        ```

        :param str resource_name: The name of the resource.
        :param RoleAssignmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleAssignmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 role_uid: Optional[pulumi.Input[str]] = None,
                 service_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleAssignmentArgs.__new__(RoleAssignmentArgs)

            __props__.__dict__["org_id"] = org_id
            if role_uid is None and not opts.urn:
                raise TypeError("Missing required property 'role_uid'")
            __props__.__dict__["role_uid"] = role_uid
            __props__.__dict__["service_accounts"] = service_accounts
            __props__.__dict__["teams"] = teams
            __props__.__dict__["users"] = users
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/roleAssignment:RoleAssignment")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(RoleAssignment, __self__).__init__(
            'grafana:enterprise/roleAssignment:RoleAssignment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            role_uid: Optional[pulumi.Input[str]] = None,
            service_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None) -> 'RoleAssignment':
        """
        Get an existing RoleAssignment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] role_uid: Grafana RBAC role UID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] service_accounts: IDs of service accounts that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: IDs of teams that the role should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] users: IDs of users that the role should be assigned to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleAssignmentState.__new__(_RoleAssignmentState)

        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["role_uid"] = role_uid
        __props__.__dict__["service_accounts"] = service_accounts
        __props__.__dict__["teams"] = teams
        __props__.__dict__["users"] = users
        return RoleAssignment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="roleUid")
    def role_uid(self) -> pulumi.Output[str]:
        """
        Grafana RBAC role UID.
        """
        return pulumi.get(self, "role_uid")

    @property
    @pulumi.getter(name="serviceAccounts")
    def service_accounts(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        IDs of service accounts that the role should be assigned to.
        """
        return pulumi.get(self, "service_accounts")

    @property
    @pulumi.getter
    def teams(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        IDs of teams that the role should be assigned to.
        """
        return pulumi.get(self, "teams")

    @property
    @pulumi.getter
    def users(self) -> pulumi.Output[Optional[Sequence[int]]]:
        """
        IDs of users that the role should be assigned to.
        """
        return pulumi.get(self, "users")

